Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(246)

Unified Diff: webkit/glue/resource_loader_bridge.h

Issue 7602023: Use a monotonic clock (TimeTicks) to report network times to WebCore. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync & Merge Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_request.cc ('k') | webkit/glue/weburlloader_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/resource_loader_bridge.h
diff --git a/webkit/glue/resource_loader_bridge.h b/webkit/glue/resource_loader_bridge.h
index 8976463a5afcd6e830bacd702c4d2f72cd2bfccd..c86b998aa9f1fd07d5b1d0ae93b443bbe7dd8a1e 100644
--- a/webkit/glue/resource_loader_bridge.h
+++ b/webkit/glue/resource_loader_bridge.h
@@ -53,8 +53,11 @@ struct ResourceLoadTimingInfo {
WEBKIT_GLUE_EXPORT ResourceLoadTimingInfo();
WEBKIT_GLUE_EXPORT ~ResourceLoadTimingInfo();
- // All the values in this struct are given as offsets in milliseconds wrt
- // this base time.
+ // All the values in this struct are given as offsets in ticks wrt
+ // this base tick count.
+ base::TimeTicks base_ticks;
+
+ // The value of Time::Now() when base_ticks was set.
base::Time base_time;
// The time that proxy processing started. For requests with no proxy phase,
@@ -329,9 +332,10 @@ class ResourceLoaderBridge {
// Called when the response is complete. This method signals completion of
// the resource load.ff
- virtual void OnCompletedRequest(const net::URLRequestStatus& status,
- const std::string& security_info,
- const base::Time& completion_time) = 0;
+ virtual void OnCompletedRequest(
+ const net::URLRequestStatus& status,
+ const std::string& security_info,
+ const base::TimeTicks& completion_time) = 0;
};
// use WebKitPlatformSupportImpl::CreateResourceLoader() for construction, but
« no previous file with comments | « net/url_request/url_request.cc ('k') | webkit/glue/weburlloader_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698